/*
 * HTML to LaTeX mod ELM
 *   
 *  Copyright (C) 2006, 2010 Michal Kebrt
 *  Copyright (C) 2015 Francesco Santeramo
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Michal Kebrt is the author of the htmltolatex project, created in 2006
 *  and with a stable version released in 2010. The project in 2015 has been
 *  modified by Francesco Santeramo, becoming the htmltolatexmodelm
 *  library, released under GPLv3 with the permission of Michal Kebrt and 
 *  used in the development of the Event Log Manager (Open Source project). 	
 */

package cz.kebrt.html2latex;

import java.util.HashMap;


/**
 *  Handles events sent from the CSS Parser.
 */
class CSSParserHandler implements ICSSParserHandler {
    
    /**
     * Html2latex program configuration.
     */
    private Configuration _config;
    /**
     * Cstr.
     * @param config program configuration
     */
    public CSSParserHandler(Configuration config) {
        _config = config;
    }

    
    /**
     * Called when a new style is reached in the CSS stylesheet.
     * Splits up multiple style names (ie. <code>h1, h2, h3 { ... } </code>)
     * and sets style properties for each of the style names.
     * @param styleName name of the style
     * @param properties map with all the style's properties
    */    
    public void newStyle(String styleName, HashMap<String, String> properties) {
        // split up multiple names (ie. h1, h2, h3 { ... } )
        String[] split = styleName.toLowerCase().split(","); 
    
        for (int i = 0; i < split.length; ++i) {
            String name = split[i].trim();
            CSSStyle style = _config.getStyle(name);
            // not in the config yet
            if (style == null) {
                style = new CSSStyle(name);
                _config.addStyle(name, style);
            }            
            style.setProperties(properties);
        }                       
    }
}
