/*
 * HTML to LaTeX mod ELM
 *   
 *  Copyright (C) 2006, 2010 Michal Kebrt
 *  Copyright (C) 2015 Francesco Santeramo
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Michal Kebrt is the author of the htmltolatex project, created in 2006
 *  and with a stable version released in 2010. The project in 2015 has been
 *  modified by Francesco Santeramo, becoming the htmltolatexmodelm
 *  library, released under GPLv3 with the permission of Michal Kebrt and 
 *  used in the development of the Event Log Manager (Open Source project). 	
 */

package cz.kebrt.html2latex;


/**
 *  Handles events sent from the {@link Parser Parser} class.
 */
public interface IParserHandler {
    
     /**
     * Called when a start element is reached in the input document.
     * @param element start element reached 
     */
    public void startElement(ElementStart element);
    
    
    /**
     * Called when an end element is reached in the input document.
     * @param element end element reached
     * @param elementStart corresponding start element
     */      
    public void endElement(ElementEnd element, ElementStart elementStart);
    
    
    /**
     * Called when the text content of an element is read.
     * @param content ie. &quot;foo&quot; for the &quot;&lt;b&gt;foo&lt;/b&gt;&quot; 
    */    
    public void characters(String content);
    
    
    /**
     * Called when the comment is reached in input document.
     * @param comment ie. &quot;foo&quot; for the &quot;&lt;!--&gt;foo&lt;/--&gt;&quot; 
    */       
    public void comment(String comment);
    
    
    /**
     * Called when the whole input document is read.
    */    
    public void endDocument();
    
}
