/*
 * HTML to LaTeX mod ELM
 *   
 *  Copyright (C) 2006, 2010 Michal Kebrt
 *  Copyright (C) 2015 Francesco Santeramo
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Michal Kebrt is the author of the htmltolatex project, created in 2006
 *  and with a stable version released in 2010. The project in 2015 has been
 *  modified by Francesco Santeramo, becoming the htmltolatexmodelm
 *  library, released under GPLv3 with the permission of Michal Kebrt and 
 *  used in the development of the Event Log Manager (Open Source project). 	
 */

package cz.kebrt.html2latex;

import java.util.HashMap;


/**
 *  Class representing HTML start element.
*/
class ElementStart extends MyElement {
    
    /** Map containing all element's attributtes with their values. */
    private HashMap<String, String> _attributes;
    
    /**
     * Cstr.
     * @param element element's name
     * @param attributes element's attributes
     */
    public ElementStart(String element, HashMap<String, String> attributes) {
        _element = element;
        _attributes = attributes;
    }
    
    /**
     * Returns element's attributes.
     * @return element's attributes
     */
    HashMap<String, String> getAttributes() { return _attributes; }
      
}


/**
 *  Class representing HTML end element.
*/
class ElementEnd extends MyElement {
    
    /**
     * Cstr.
     * @param element element's name
     */
    ElementEnd(String element) {
        _element = element;
    }
}


/**
 * Abstract class for HTML start and end elements (tags).
*/
abstract class MyElement {
    /** Element's name */
    protected String _element;
    
    /**
     * Returns element's name.
     * @return element's name
     */
    String getElementName() { return _element; }
}


