/*
 * Event Log Manager
 *   
 *  Copyright (C) 2015 Francesco Santeramo
 *
 *  This file is part of Event Log Manager.
 *
 *  Event Log Manager is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Event Log Manager is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *	
 *  Author:  Francesco Santeramo 
 *  Website: www.francescosanteramo.com
 *  Contact: eventlogmanager@francescosanteramo.com    
 */

package unipi.bpm.elm.santeramo.starter;

import java.awt.Color;
import java.awt.EventQueue;
import java.awt.Insets;
import java.util.Locale;

import javax.swing.JOptionPane;
import javax.swing.UIManager;
import javax.swing.UnsupportedLookAndFeelException;

import unipi.bpm.elm.santeramo.controller.EventLogManagerController;
import unipi.bpm.elm.santeramo.model.EventLogManagerModel;
import unipi.bpm.elm.santeramo.view.EventLogManagerView;

/**
 * This class contains the <code>main</code> method for starting the application.
 * 
 * @author Francesco Santeramo (eventlogmanager@francescosanteramo.com)
 */
public class EventLogManagerStarter {
	/**
	 * Launches the Event Logs Manager application.
	 * 
	 * <p>This method first selects the graphics for the application, according
	 * to the Operating System, then initialises all the components of the MVC pattern
	 * and launches the application by starting the View.
	 * 
	 * @param args unused
	 */
	public static void main(String[] args) {	
		
		// set the standard language to English
		Locale.setDefault(Locale.UK);
		
		// class name of the selected Look and Feel
		String className = UIManager.getSystemLookAndFeelClassName();			
		
		try {
			UIManager.setLookAndFeel(className); // set the selected Look and Feel
		} catch (ClassNotFoundException | InstantiationException | IllegalAccessException | UnsupportedLookAndFeelException e) {
			JOptionPane.showMessageDialog(null, "The application was not able to load the correct graphics for this Operating System. " +
					"Java default graphics has been selected.", "Event Log Manager Warning System", JOptionPane.WARNING_MESSAGE);
		}
			
		// set specific graphic properties for this application
		Insets currentInsets;		
		// remove dots around a selected tab
    	UIManager.put("TabbedPane.focus", new Color(0, 0, 0, 0));    	    	   	
    	// margin around a tab
    	currentInsets = UIManager.getInsets("TabbedPane.tabAreaInsets");
    	UIManager.put("TabbedPane.tabAreaInsets", new Insets(currentInsets.top, 5, currentInsets.bottom, currentInsets.right));    	
    	// padding inside a tab
    	currentInsets = UIManager.getInsets ( "TabbedPane.tabInsets" );
        UIManager.put("TabbedPane.tabInsets", new Insets(currentInsets.top+2, 15, currentInsets.bottom+2, 15));
        // padding of the tab area
        currentInsets = UIManager.getInsets ( "TabbedPane.contentBorderInsets" );
        UIManager.getDefaults().put("TabbedPane.contentBorderInsets", new Insets(0,currentInsets.left,currentInsets.bottom,currentInsets.right));    
       
        // start the application
        EventQueue.invokeLater(new Runnable() {
			public void run() {				
				// instantiate the View but don't show it yet.
				EventLogManagerView elmView = new EventLogManagerView(); 

				// instantiate the Model
				EventLogManagerModel elmModel = new EventLogManagerModel(); 
				// instantiate the Controller
				EventLogManagerController elmController = new EventLogManagerController(elmView, elmModel);
				
				// start the application
				elmController.start(); 
			}
        });
	}
}
